==> haskell-project-template-0.2.1.0-474-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 project-template
version:              0.2.1.0
visibility:           public
id:                   project-template-0.2.1.0-1bNKc74sekh8Il9CbPkBfg
key:                  project-template-0.2.1.0-1bNKc74sekh8Il9CbPkBfg
license:              BSD-3-Clause
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/haskell-ide
synopsis:             Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>

category:             Development
abi:                  7261ec374547de2447d1bfaea1365260
exposed:              True
exposed-modules:      Text.ProjectTemplate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/project-template-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/project-template-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/project-template-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-project-template
hs-libraries:         HSproject-template-0.2.1.0-1bNKc74sekh8Il9CbPkBfg
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-KTcFt1JBtqE6XrF8UIUkhn
    bytestring-0.11.5.3 conduit-1.3.6.1-JCExIuyhnVmH352zfSD7FS
    conduit-extra-1.3.8-E2T0R9dVEp0LoFKbSS1RVP containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    resourcet-1.2.6-BKqjD5gnFNM38kSitAkGef text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-project-template/html/project-template.haddock

haddock-html:         /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-project-template-0.2.1.0-475-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 project-template
version:              0.2.1.0
visibility:           public
id:                   project-template-0.2.1.0-3lrVgOFIXG2CtumWoFaPQh
key:                  project-template-0.2.1.0-3lrVgOFIXG2CtumWoFaPQh
license:              BSD-3-Clause
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/haskell-ide
synopsis:             Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>

category:             Development
abi:                  c916ca4ba841923f068e787ab8d00de2
exposed:              True
exposed-modules:      Text.ProjectTemplate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/project-template-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/project-template-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/project-template-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-project-template
hs-libraries:         HSproject-template-0.2.1.0-3lrVgOFIXG2CtumWoFaPQh
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-2WioaI2OOHv6enJjm95P5G
    bytestring-0.11.5.3 conduit-1.3.6.1-7gDrgQT36z4IN6MqKXM4jU
    conduit-extra-1.3.8-LH0nSmNEDBz6QpPwrMyaiE containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    resourcet-1.2.6-2BcDKwHjSabK2j2MMy69bs text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-project-template/html/project-template.haddock

haddock-html:         /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
